Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1370)

Unified Diff: recipes/crashpad.py

Issue 1416663003: Add a fetch recipe for Crashpad (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipes/crashpad.py
diff --git a/recipes/dart.py b/recipes/crashpad.py
similarity index 55%
copy from recipes/dart.py
copy to recipes/crashpad.py
index 2b4d78c0f25b820b9e43b2e70512cd0051737434..7342300bedb9355694e3e3949ffe1161ed4ce196 100644
--- a/recipes/dart.py
+++ b/recipes/crashpad.py
@@ -9,25 +9,20 @@ import recipe_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Dart(recipe_util.Recipe):
- """Basic Recipe class for Dart."""
+class CrashpadRecipe(recipe_util.Recipe):
+ """Basic Recipe class for Crashpad."""
@staticmethod
def fetch_spec(props):
- url = 'https://github.com/dart-lang/sdk.git'
- solution = {
- 'name' :'sdk',
- 'url' : url,
- 'deps_file': 'DEPS',
- 'managed' : False,
- 'custom_deps': {},
- 'safesync_url': '',
- }
spec = {
- 'solutions': [solution],
+ 'solutions': [
+ {
+ 'name': 'crashpad',
+ 'url': 'https://chromium.googlesource.com/crashpad/crashpad.git',
+ 'managed': False,
+ },
+ ],
}
- if props.get('target_os'):
- spec['target_os'] = props['target_os'].split(',')
return {
'type': 'gclient_git',
'gclient_git_spec': spec,
@@ -35,11 +30,11 @@ class Dart(recipe_util.Recipe):
@staticmethod
def expected_root(_props):
- return 'sdk'
+ return 'crashpad'
def main(argv=None):
- return Dart().handle_args(argv)
+ return CrashpadRecipe().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698